@@ -25,5 +25,5 @@ eg:
 my_yaml=DoYaml(filename)
 res=my_yaml.read_config()
 """
-__all__ = ["DoYaml", "read_config", "get_data_one",
-           "get_data_all", "insert_or_update_data", "insert_data_list", "time_used", "FakerMaker"]
+# __all__ = ["DoYaml", "read_config", "get_data_one",
+#            "get_data_all", "insert_or_update_data", "insert_data_list", "time_used", "FakerMaker"]
